@@ -1,7 +1,7 @@
 # pylint: disable=unused-argument,invalid-name,line-too-long
 from __future__ import annotations
 
-from typing import List, Optional
+from typing import List
 
 from parse import parse
 from sqlalchemy import text as sql_text
@@ -11,24 +11,28 @@ from alembic_utils.replaceable_entity import ReplaceableEntity
 
 
 class PGView(ReplaceableEntity):
-    """ A PostgreSQL View that can be versioned and replaced """
+    """A PostgreSQL View compatible with `alembic revision --autogenerate`
+
+    **Parameters:**
+
+    * **schema** - *str*: A SQL schema name
+    * **signature** - *str*: A SQL view's call signature
+    * **definition** - *str*: The SQL select statement body of the view
+    """
 
     @classmethod
-    def from_sql(cls, sql: str) -> Optional[PGView]:
-        """Create an instance of PGFunction from a blob of sql"""
-        templates = [
-            "create{}view{:s}{schema}.{signature}{:s}as{:s}{definition}",
-        ]
-        for template in templates:
-            result = parse(template, sql, case_sensitive=False)
-            if result is not None:
-                return cls(
-                    schema=result["schema"],
-                    signature=result["signature"],
-                    definition=result["definition"],
-                )
+    def from_sql(cls, sql: str) -> PGView:
+        """Create an instance from a SQL string"""
+        template = "create{}view{:s}{schema}.{signature}{:s}as{:s}{definition}"
+        result = parse(template, sql, case_sensitive=False)
+        if result is not None:
+            return cls(
+                schema=result["schema"],
+                signature=result["signature"],
+                definition=result["definition"],
+            )
 
-        raise SQLParseFailure(sql)
+        raise SQLParseFailure(f'Failed to parse SQL into PGView """{sql}"""')
 
     def to_sql_statement_create(self) -> str:
         """Generates a SQL "create view" statement"""
@@ -40,7 +44,9 @@ class PGView(ReplaceableEntity):
 
     def to_sql_statement_create_or_replace(self) -> str:
         """Generates a SQL "create or replace view" statement"""
-        return sql_text(f"CREATE OR REPLACE VIEW {self.schema}.{self.signature} AS {self.definition}")
+        return sql_text(
+            f"CREATE OR REPLACE VIEW {self.schema}.{self.signature} AS {self.definition}"
+        )
 
     @classmethod
     def from_database(cls, connection, schema="%") -> List[PGView]:
